# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_without javadoc
%bcond_without repolib

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define repodir %{_javadir}/repository.jboss.com/org/slf4j/%{namedversion}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define patchtag -patch-01
%define brewtag _patch_01

%global namedversion %{version}%{?patchtag}

%define section free

Name:           slf4j
Version:        1.5.8
Release:        10%{brewtag}.2%{?dist}
Epoch:          0
Summary:        Simple Logging Facade for Java
Group:          System/Logging
License:        MIT
URL:            http://www.slf4j.org/
Source0:        http://www.slf4j.org/dist/slf4j-1.5.8.tar.gz
Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml
Source3:        slf4j-component-info.xml
Source4:        slf4j-upload.sh
Patch0:         %{name}-pom_xml.patch
Patch1:         slf4j-1.5.8-skip-integration-tests.patch
Patch2:         slf4j-pom_version.patch
# Patch3 Patch SLF4J API to resolve an NPE when SLF4J exits in the endorsed subdirectory 
Patch3:         slf4j-JBPAPP-6046.patch

Requires(post): jpackage-utils >= 0:1.7.3
Requires(postun): jpackage-utils >= 0:1.7.3

BuildRequires:  jpackage-utils >= 0:1.7.3
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  ant >= 0:1.6.5
BuildRequires:  ant-junit >= 0:1.6.5
BuildRequires:  javassist >= 0:3.4
BuildRequires:  junit >= 0:3.8.2
BuildRequires:  maven2 >= 2.0.7
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-source
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  avalon-framework
BuildRequires:  log4j
BuildRequires:  jakarta-commons-logging
BuildRequires:  maven2-plugin-site
# To create content for maven2-brew
BuildRequires:  maven2-plugin-deploy
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The Simple Logging Facade for Java or (SLF4J) is intended to serve
as a simple facade for various logging APIs allowing to the end-user
to plug in the desired implementation at deployment time. SLF4J also
allows for a gradual migration path away from
Jakarta Commons Logging (JCL). 

Logging API implementations can either choose to implement the
SLF4J interfaces directly, e.g. NLOG4J or SimpleLogger. Alternatively,
it is possible (and rather easy) to write SLF4J adapters for the given
API implementation, e.g. Log4jLoggerAdapter or JDK14LoggerAdapter.. 

%if %without javadoc
%package javadoc
Group:          Development/Documentation
Summary:        Javadoc for %{name}
Requires:       jpackage-utils

%description javadoc
%{summary}.
%endif

%package manual
Group:          Development/Documentation
Summary:        Documents for %{name}

%description manual
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q
%patch0 -p0
%patch1 -p1
%patch2 -p1
%patch3 -p1
find . -name "*.jar" | xargs rm

%if 0
cp -p %{SOURCE1} settings.xml

sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
sed -i -e "s|<url>__ECLIPSEDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/eclipse/plugins</url>|g" settings.xml

mkdir external_repo
ln -s %{_javadir} external_repo/JPP

export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL/org.slf4j
ln -sf $(build-classpath maven2/empty-dep) $MAVEN_REPO_LOCAL/org.slf4j/slf4j-api.jar
ln -sf $(build-classpath maven2/empty-dep) $MAVEN_REPO_LOCAL/org.slf4j/slf4j-simple.jar
ln -sf $(build-classpath maven2/empty-dep) $MAVEN_REPO_LOCAL/org.slf4j/slf4j-log4j12.jar
ln -sf $(build-classpath maven2/empty-dep) $MAVEN_REPO_LOCAL/org.slf4j/slf4j-nop.jar
%endif

%{_bindir}/find -name "*.css" -o -name "*.js" -o -name "*.txt" | %{_bindir}/xargs -t %{__perl} -pi -e 's/\r$//g'

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository

mvn-jpp \
        -e \
        -s $(pwd)/settings.xml \
        -Dmaven2.jpp.mode=true \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        -Dmaven.test.failure.ignore=true \
	%if %without javadoc
            install javadoc:javadoc
	%else
	    install
	%endif

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/%{name}

#install -m 644 jcl104-over-slf4j/target/jcl104-over-slf4j-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/jcl104-over-slf4j-%{namedversion}.jar
ln -sf jcl-over-slf4j-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/jcl104-over-slf4j-%{namedversion}.jar
install -m 644 jcl-over-slf4j/target/jcl-over-slf4j-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/jcl-over-slf4j-%{namedversion}.jar
install -m 644 jul-to-slf4j/target/jul-to-slf4j-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/jul-to-slf4j-%{namedversion}.jar
install -m 644 log4j-over-slf4j/target/log4j-over-slf4j-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/log4j-over-slf4j-%{namedversion}.jar
install -m 644 slf4j-api/target/%{name}-api-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/api-%{namedversion}.jar
install -m 644 slf4j-api/target/%{name}-api-%{namedversion}-tests.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/api-tests-%{namedversion}.jar
install -m 644 slf4j-ext/target/%{name}-ext-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/ext-%{namedversion}.jar
install -m 644 slf4j-jcl/target/%{name}-jcl-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/jcl-%{namedversion}.jar
install -m 644 slf4j-jdk14/target/%{name}-jdk14-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/jdk14-%{namedversion}.jar
install -m 644 slf4j-log4j12/target/%{name}-log4j12-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/log4j12-%{namedversion}.jar
install -m 644 slf4j-migrator/target/%{name}-migrator-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/migrator-%{namedversion}.jar
install -m 644 slf4j-nop/target/%{name}-nop-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/nop-%{namedversion}.jar
install -m 644 slf4j-simple/target/%{name}-simple-%{namedversion}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/simple-%{namedversion}.jar

(cd $RPM_BUILD_ROOT%{_javadir}/%{name} && for jar in *-%{namedversion}*; do ln -sf ${jar} `echo $jar| sed "s|-%{namedversion}||g"`; done)

%add_to_maven_depmap org.slf4j jcl104-over-slf4j %{namedversion} JPP/%{name} jcl104-over-slf4j
%add_to_maven_depmap org.slf4j jcl-over-slf4j %{namedversion} JPP/%{name} jcl-over-slf4j
%add_to_maven_depmap org.slf4j jul-to-slf4j %{namedversion} JPP/%{name} jul-to-slf4j
%add_to_maven_depmap org.slf4j log4j-over-slf4j %{namedversion} JPP/%{name} log4j-over-slf4j
%add_to_maven_depmap org.slf4j %{name}-parent %{namedversion} JPP/%{name} parent
%add_to_maven_depmap org.slf4j %{name}-api %{namedversion} JPP/%{name} api
%add_to_maven_depmap org.slf4j %{name}-ext %{namedversion} JPP/%{name} ext
%add_to_maven_depmap org.slf4j %{name}-jcl %{namedversion} JPP/%{name} jcl
%add_to_maven_depmap org.slf4j %{name}-jdk14 %{namedversion} JPP/%{name} jdk14
%add_to_maven_depmap org.slf4j %{name}-log4j12 %{namedversion} JPP/%{name} log4j12
%add_to_maven_depmap org.slf4j %{name}-migrator %{namedversion} JPP/%{name} migrator
%add_to_maven_depmap org.slf4j %{name}-nop %{namedversion} JPP/%{name} nop
%add_to_maven_depmap org.slf4j %{name}-simple %{namedversion} JPP/%{name} simple

# poms
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -pm 644 pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-parent.pom
install -pm 644 jcl104-over-slf4j/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-jcl104-over-slf4j.pom
install -pm 644 jcl-over-slf4j/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-jcl-over-slf4j.pom
install -pm 644 jul-to-slf4j/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-jul-to-slf4j.pom
install -pm 644 log4j-over-slf4j/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-log4j-over-slf4j.pom
install -pm 644 slf4j-api/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-api.pom
install -pm 644 slf4j-ext/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-ext.pom
install -pm 644 slf4j-jcl/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-jcl.pom
install -pm 644 slf4j-jdk14/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-jdk14.pom
install -pm 644 slf4j-log4j12/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-log4j12.pom
install -pm 644 slf4j-migrator/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-migrator.pom
install -pm 644 slf4j-nop/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-nop.pom
install -pm 644 slf4j-simple/pom.xml \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}-simple.pom

# javadoc
%if %without javadoc
install -d -m 0755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{namedversion}
cp -pr target/site/api*/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{namedversion}/
ln -s %{name}-%{namedversion} $RPM_BUILD_ROOT%{_javadocdir}/%{name}
rm -rf target/site/api*
%endif

# manual
install -d -m 0755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{namedversion}
cp -pr target/site/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{namedversion}/
install -m 644 LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{namedversion}/

%if %with repolib
%{__install} -d -m 755 %{buildroot}%{repodir}
%{__install} -d -m 755 %{buildroot}%{repodirlib}
%{__install} -p -m 644 %{SOURCE3} %{buildroot}%{repodir}/component-info.xml
tag=`/bin/echo %{name}-%{version}-%{release} | %{__sed} 's|\.|_|g'`
%{__sed} -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
%{__sed} -i "s/@VERSION@/%{namedversion}-brew/g" %{buildroot}%{repodir}/component-info.xml
%{__install} -d -m 755 %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{SOURCE0} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{SOURCE1} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{SOURCE2} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{PATCH0} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{PATCH1} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{PATCH2} %{buildroot}%{repodirsrc}
%{__install} -p -m 644 %{PATCH3} %{buildroot}%{repodirsrc}

%{__cp} -p %{buildroot}%{_javadir}/%{name}/jcl-over-slf4j-%{namedversion}.jar %{buildroot}%{repodirlib}/jcl-over-slf4j.jar
%{__install} -p -m 644 jcl-over-slf4j/pom.xml %{buildroot}%{repodirlib}/jcl-over-slf4j.pom

%{__cp} -p %{buildroot}%{_javadir}/%{name}/api-%{namedversion}.jar %{buildroot}%{repodirlib}/slf4j-api.jar
%{__install} -p -m 644 slf4j-api/pom.xml %{buildroot}%{repodirlib}/slf4j-api.pom

%{__cp} -p %{buildroot}%{_javadir}/%{name}/jcl-%{namedversion}.jar %{buildroot}%{repodirlib}/slf4j-jcl.jar
%{__install} -p -m 644 slf4j-jcl/pom.xml %{buildroot}%{repodirlib}/slf4j-jcl.pom

%{__cp} -p %{buildroot}%{_javadir}/%{name}/log4j12-%{namedversion}.jar %{buildroot}%{repodirlib}/slf4j-log4j12.jar
%{__install} -p -m 644 slf4j-log4j12/pom.xml %{buildroot}%{repodirlib}/slf4j-log4j12.pom

%{__cp} -p %{buildroot}%{_javadir}/%{name}/nop-%{namedversion}.jar %{buildroot}%{repodirlib}/slf4j-nop.jar
%{__install} -p -m 644 slf4j-nop/pom.xml %{buildroot}%{repodirlib}/slf4j-nop.pom

%{__install} -p -m 644 pom.xml %{buildroot}%{repodirlib}/slf4j-parent.pom

%{__cp} -p %{buildroot}%{_javadir}/%{name}/simple-%{namedversion}.jar %{buildroot}%{repodirlib}/slf4j-simple.jar
%{__install} -p -m 644 slf4j-simple/pom.xml %{buildroot}%{repodirlib}/slf4j-simple.pom

%{__install} -p -m 755 %{SOURCE4} %{buildroot}%{repodir}/upload.sh
pushd %{buildroot}%{repodir}
./upload.sh %{buildroot}/usr/share/java/repository.jboss.com/maven2-brew/
popd
%endif

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%dir %{_docdir}/%{name}-%{namedversion}
%doc %{_docdir}/%{name}-%{namedversion}/LICENSE.txt
%{_javadir}/%{name}
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/*-%{namedversion}.jar.*
%endif

%if %without javadoc
%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{namedversion}
%{_javadocdir}/%{name}
%endif

%files manual
%defattr(0644,root,root,0755)
%{_docdir}/%{name}-%{namedversion}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}/repository.jboss.com
%endif

%changelog
* Tue Sep  6 2011 Dustin Kut Moy Cheung <dcheung@redhat.com> - 0:1.5.8-10_patch_01.2
- Rebuild
- Porting changes from RHEL6 branch

* Tue Aug 23 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.5.8-10_patch_01.1
- Rebuild

* Sun Jun 12 2011 David Walluck <dwalluck@redhat.com> 0:1.5.8-10_patch_01
- install missing jdk14 jar
- fix install by using proper version
- fix maven depmaps
- use deploy

* Tue Mar 08 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.5.8-9_patch_01.2
- Rebuild

* Tue Mar 08 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.5.8-9_patch_01.1
- Upgrade to 1.5.8-patch-01

* Wed Feb 09 2011 David Walluck <dwalluck@redhat.com> 0:1.5.8-8
- bump release to be newer than 7.el6
- always build javadoc
- javadoc Requires: jpackage-utils
- change BuildRequires to be backwards compat with old maven2
- fix manual

* Tue Dec 21 2010 Hui Wang <huwang@redhat.com> - 0:1.5.8-4
- Add missing artifacts to repolib

* Tue Dec 21 2010 Hui Wang <huwang@redhat.com> - 0:1.5.8-3
- Eliminate slf4j-jdk14

* Wed Dec 08 2010 Hui Wang <huwang@redhat.com> - 0:1.5.8-2
- Add upload.sh and content of maven2-brew to repolib
- Fix %%files for signed jars
- Add BR maven-site-plugin

* Fri Nov 05 2010 Permaine Cheung <pcheung@redhat.com> - 0:1.5.8-1.3.1
- Fix repolib location

* Mon May 17 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.5.8-1.2.1
- rebuilt

* Mon Apr 19 2010 Yiqiao Wang <yiwang@redhat.com> 0:1.5.8-1.2
- Rebuild

* Mon Jan 18 2010 David Walluck <dwalluck@redhat.com> 0:1.5.8-1.1.1
- fix GCJ support

* Wed Jul 29 2009 Yong Yang <yyang@redhat.com> 0:1.5.8-1.1
- 1.5.8
- Replace slf4j-1.5.6-integration-tests-current-only.patch with slf4j-1.5.8-skip-integration-tests.patch because of the failure of "testMatch"

* Tue Jun 23 2009 Martha Benitez <mbenitez@redhat.com> 0:1.5.6-2.1
- Change jpackage-utils >= 0:1.7.5 to jpackage-utils >= 0:1.7.3
- Change BR excalibur-avalon-framework to avalon-framework
- Add condition to build with(out) javadoc
- Add -Dmaven.test.failure.ignore=true

* Fri Jun 12 2009 Ralph Apel <r.apel at r-apel.de> 0:1.5.6-2
- Add -ext jar, depmap and pom
- Save jcl104-over-slf4j as symlink

* Tue Feb 18 2009 David Walluck <dwalluck@redhat.com> 0:1.5.6-1
- 1.5.6
- add repolib
- fix file eol
- fix Release tag

* Fri Jul 18 2008 David Walluck <dwalluck@redhat.com> 0:1.5.2-2
- use excalibur for avalon
- remove javadoc scriptlets
- GCJ fixes
- fix maven directory ownership
- fix -bc --short-circuit by moving some of %%build to %%prep

* Sun Jul 06 2008 Ralph Apel <r.apel at r-apel.de> 0:1.5.2-1.jpp5
- 1.5.2

* Mon Feb 04 2008 Ralph Apel <r.apel at r-apel.de> 0:1.4.2-2jpp
- Fix macro misprint
- Add maven2-plugin BRs

* Wed Jul 18 2007 Ralph Apel <r.apel at r-apel.de> 0:1.4.2-1jpp
- Upgrade to 1.4.2
- Build with maven2
- Add poms and depmap frags
- Add gcj_support option

* Mon Jan 30 2006 Ralph Apel <r.apel at r-apel.de> 0:1.0-0.rc5.1jpp
- First JPackage release.
